@@ -16,10 +16,10 @@
 # this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 
+from .artifact import Artifact, ArtifactPlugin
 from .branch import BranchPlugin
-from .build import Build, BuildPlugin
+from .run import RunPlugin
 from .clone import ClonePlugin
 from .config import ConfigPlugin
-from .configure import Configure, ConfigurePlugin
-from .install import Install, InstallPlugin
+from .help import Help, HelpPlugin
 from .worktree import Worktree, WorktreePlugin
